@@ -3,12 +3,15 @@
 # All rights reserved.
 # This file is distributed under the BSD 3-Clause License.
 #
-from django.contrib.postgres.fields import jsonb
+try:
+    from django.db.models import JSONField as BaseJSONField
+except ImportError:
+    from django.contrib.postgres.fields.jsonb import JSONField as BaseJSONField
 from djangokit.forms.postgres import JSONField as FormJSONField
 from djangokit.utils.encoders import JSONEncoder
 
 
-class JSONField(jsonb.JSONField):
+class JSONField(BaseJSONField):
     """Django PostgreSQL JSONField with custom encoder."""
 
     def __init__(self, *args, **kwargs):
