@@ -11,7 +11,7 @@ class ColorFormatter(logging.Formatter):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.style = color_style()
+        self.style = color_style(force_color=True)
         self.setup_colorizers()
 
     def setup_colorizers(self):
