@@ -14,3 +14,10 @@ def jsondumps(data, indent=None):
     if data is None:
         return ''
     return dump_to_json(data, indent=indent)
+
+
+@register.filter
+def jsondumps_unicode(data, indent=None):
+    if data is None:
+        return ''
+    return dump_to_json(data, indent=indent, ensure_ascii=False)
