@@ -12,7 +12,7 @@ def remove_file(filename):
     try:
         os.remove(filename)
         return True
-    except Exception:
+    except OSError:
         return False
 
 
@@ -24,7 +24,7 @@ def remove_dirs(dirname, withfiles=False):
     try:
         os.removedirs(dirname)
         return True
-    except Exception:
+    except OSError:
         return False
 
 
