@@ -36,10 +36,12 @@ class Controller:
     prefetch_related = None
     serializer = None
     use_distinct = False
+    default_ordering = None
 
     def __init__(self, model=None, search_fields=None, ordering_fields=None,
                  filtering_fields=None, exclude_fields=None, serializer=None,
-                 select_related=None, prefetch_related=None):
+                 select_related=None, prefetch_related=None,
+                 default_ordering=None):
         if model:
             self.model = model
         else:
@@ -76,6 +78,11 @@ class Controller:
         else:
             orig_name = 'djangokit.Controller'
         self.logger = getLogger(orig_name + '(' + str(meta) + ')')
+        # Устанавливаем дефолтную сортировку.
+        if default_ordering is not None:
+            self.default_ordering = default_ordering
+        elif not self.default_ordering:
+            self.default_ordering = meta.ordering or ('pk',)
 
     def __str__(self):
         cls = self.__class__
@@ -132,8 +139,9 @@ class Controller:
 
         if not ordering or not fields:
             # Fix UnorderedObjectListWarning:
-            if not getattr(queryset, 'ordered', True):
-                queryset = queryset.order_by('pk')
+            if not getattr(queryset, 'ordered', False):
+                queryset = queryset.order_by(*self.default_ordering)
+                logger.debug('default ordering by %s', self.default_ordering)
             return queryset, []
 
         def valid(x):
@@ -153,6 +161,10 @@ class Controller:
         if ordering:
             queryset = queryset.order_by(*ordering)
             logger.debug('ordering by %s', ordering)
+        # Fix UnorderedObjectListWarning:
+        elif not getattr(queryset, 'ordered', False):
+            queryset = queryset.order_by(*self.default_ordering)
+            logger.debug('default ordering by %s', self.default_ordering)
         return queryset, ordering
 
     def search(self, queryset, query):
