@@ -11,6 +11,7 @@ from functools import wraps
 from io import BytesIO
 
 from django.http.request import QueryDict, MultiValueDict
+from django.http.response import HttpResponseBadRequest
 from django.http.multipartparser import MultiPartParserError
 from django.utils.encoding import force_text
 from django.views.decorators.cache import cache_page
@@ -96,7 +97,7 @@ def _get_parser(request):
     return _blank_parser
 
 
-def parse_data(function=None):
+def parse_data(function=None, force_to_dict=False):
     """Декоратор для представлений, использующихся в качестве REST API."""
 
     def decorator(view_func):
@@ -109,9 +110,29 @@ def parse_data(function=None):
                 else:
                     if request._read_started and not hasattr(request, '_body'):
                         request._mark_post_parse_error()
+                        request.data = {}
                     else:
                         parser = _get_parser(request)
                         request.data, request._files = parser(request)
+            if force_to_dict:
+                data = request.data
+                if not isinstance(data, dict):
+                    request.data = data.dict()
+            return view_func(request, *args, **kwargs)
+        return _wrapped_view
+    if function:
+        return decorator(function)
+    return decorator
+
+
+def json_required(function=None):
+    def decorator(view_func):
+        @wraps(view_func)
+        def _wrapped_view(request, *args, **kwargs):
+            content_type = request.META.get('CONTENT_TYPE', '')
+            if not content_type.startswith('application/json'):
+                return HttpResponseBadRequest(
+                    'Content type of request must be "application/json".')
             return view_func(request, *args, **kwargs)
         return _wrapped_view
     if function:
