@@ -36,7 +36,7 @@ class LogReaderView(View):
         end = f.tell()
         f.close()
         return {
-            'lines': [l.decode('utf-8').rstrip('\n') for l in buf],
+            'lines': [line.decode('utf-8').rstrip('\n') for line in buf],
             'end': end,
         }
 
